What can it do?
==========

Simple wrapper around maim and xclip for doing screenshots.</br>
For help write</br>
`$ lumes -h`

Installation
------------
To upgrade pip
</br>`$ python3 -m pip install -U pip`
</br>To be sure you use proper version of python
</br>`$ python3 -m pip install lumes`
</br>To upgrade lumes
</br>`$ python3 -m pip install -U lumes`

Capabilities
-----------

1. Selection area
2. Move screen to clipboard (by default)
3. Save screenshot in file
4. Save screenshots in directory

Requirements
----------

1. maim
2. xclip

In future
----------

1. Wayland support
